@@ -3,25 +3,22 @@ import os
 import time
 
 
-def get_attributes_minio(attributes, s3_object, store):
-    attribute_list = []
-    for attribute in attributes:
-        attribute_list.append(getattr(s3_object, attribute))
-    store.append(tuple(attribute_list))
+def get_minio_object(attributes, s3_object, store):
+    store.append(s3_object)
     return store
 
 
-def get_attributes_local(files, path, store, filter_object):
+def get_attributes_local(files, path, store, ext):
     for name in files:
         mtime = os.path.getmtime(path)
-        if "excel" in filter_object:
-            filename, filename_ext = os.path.splitext(name)
-            if (filename_ext == ".xlsx") or (filename_ext == ".xls"):
-                store.append((os.path.join(path, name),
-                              datetime.datetime.strptime(time.ctime(mtime), "%a %b %d %H:%M:%S %Y")))
-        else:
+        if ext is None:
             store.append((os.path.join(path, name),
                           datetime.datetime.strptime(time.ctime(mtime), "%a %b %d %H:%M:%S %Y")))
+        else:
+            filename, filename_ext = os.path.splitext(name)
+            if filename_ext in ext:
+                store.append((os.path.join(path, name),
+                              datetime.datetime.strptime(time.ctime(mtime), "%a %b %d %H:%M:%S %Y")))
     return store
 
 
